@@ -83,7 +83,7 @@ Character = {
 --
 -- Attribute: name
 --
---   Name of character
+--   Full name of character. First name + surname.
 --
 -- Availability:
 --
@@ -93,6 +93,14 @@ Character = {
 --
 --   experimental
 --
+-- Attribute: firstname
+--
+--   First name of character.
+--
+-- Attribute: surname
+--
+--   Surname of character.
+--
 -- Attribute: female
 --
 --   Gender of character.  If true, character is female.  If false, male.
@@ -516,7 +524,10 @@ Character = {
 		setmetatable(newCharacter,Character.meta)
 		-- initialize face characteristics if they weren't fully specified
 		if newCharacter.female == nil then newCharacter.female = (rand:Integer(1) ==1) end
-		newCharacter.name = newCharacter.name or NameGen.FullName(newCharacter.female,rand)
+		if newCharacter.firstname == nil or newCharacter.surname == nil then
+			newCharacter.firstname, newCharacter.surname = NameGen.Names(newCharacter.female,rand)
+		end
+		newCharacter.name = newCharacter.firstname .. " " .. newCharacter.surname
 		newCharacter.seed = newCharacter.seed or rand:Integer()
 		newCharacter.armour = newCharacter.armour or false
 		newCharacter.player = false -- Explicitly set this, if you need it.
